@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2017 Montel Laurent <montel@kde.org>
+   Copyright (C) 2017-2018 Montel Laurent <montel@kde.org>
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public
@@ -54,7 +54,7 @@ ImportMailPluginManager *ImportMailPluginManager::self()
 bool ImportMailPluginManager::initializePluginList()
 {
     const QVector<KPluginMetaData> plugins = KPluginLoader::findPlugins(QStringLiteral("importwizard"), [](const KPluginMetaData &md) {
-        return md.serviceTypes().contains(QStringLiteral("ImportWizard/PluginMailImporter"));
+        return md.serviceTypes().contains(QLatin1String("ImportWizard/PluginMailImporter"));
     });
 
     QVectorIterator<KPluginMetaData> i(plugins);
